be-brief
===================

A Wagtail app for short form posts. Please bear with us while we prepare more detailed documentation.

Compatibility
-------------

`be-brief`'s major.minor version number indicates the Wagtail release it is compatible with. Currently this is Wagtail 4.1.x

Installation
------------

1. Install using `pip`:
  ```shell
  pip install be-brief
  ```
2. Add
   `be_brief` to your `INSTALLED_APPS` setting:
   ```python
   INSTALLED_APPS = [
     # ...
     'be_brief'
     # ...
   ]
   ```
